@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,7 +28,7 @@ class KPIMTextEdit::RichTextComposerWidgetPrivate
 {
 public:
     RichTextComposerWidgetPrivate()
-        : richTextComposer(Q_NULLPTR)
+        : richTextComposer(nullptr)
     {
 
     }
