@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -33,7 +33,7 @@ class KPIMTEXTEDIT_EXPORT InsertTableWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit InsertTableWidget(QWidget *parent = Q_NULLPTR);
+    explicit InsertTableWidget(QWidget *parent = nullptr);
     ~InsertTableWidget();
     int columns() const;
     int rows() const;
