@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,8 +28,8 @@ class KPIMTextEdit::TextToSpeechActionsPrivate
 public:
     TextToSpeechActionsPrivate()
         : mState(TextToSpeechWidget::Stop),
-          mStopAction(Q_NULLPTR),
-          mPlayPauseAction(Q_NULLPTR)
+          mStopAction(nullptr),
+          mPlayPauseAction(nullptr)
     {
 
     }
